@@ -33,9 +33,9 @@ from PyQt5.QtCore import QUrl, pyqtSignal, pyqtSlot
 from PyQt5.QtWidgets import QMenuBar, QAction
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import nwDocAction, nwDocInsert, nwWidget
 from novelwriter.common import openExternalPath
 from novelwriter.constants import nwConst, trConst, nwKeyWords, nwLabels, nwUnicode
+from novelwriter.enum import nwDocAction, nwDocInsert, nwView, nwWidget
 from novelwriter.extensions.eventfilters import StatusTipFilter
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -55,6 +55,7 @@ class GuiMainMenu(QMenuBar):
     requestDocInsertText = pyqtSignal(str)
     requestDocKeyWordInsert = pyqtSignal(str)
     requestFocusChange = pyqtSignal(nwWidget)
+    requestViewChange = pyqtSignal(nwView)
 
     def __init__(self, mainGui: GuiMain) -> None:
         super().__init__(parent=mainGui)
@@ -196,12 +197,12 @@ class GuiMainMenu(QMenuBar):
         # Document > Open
         self.aOpenDoc = self.docuMenu.addAction(self.tr("Open Document"))
         self.aOpenDoc.setShortcut("Ctrl+O")
-        self.aOpenDoc.triggered.connect(lambda: self.mainGui.openSelectedItem())
+        self.aOpenDoc.triggered.connect(self.mainGui.openSelectedItem)
 
         # Document > Save
         self.aSaveDoc = self.docuMenu.addAction(self.tr("Save Document"))
         self.aSaveDoc.setShortcut("Ctrl+S")
-        self.aSaveDoc.triggered.connect(lambda: self.mainGui.saveDocument())
+        self.aSaveDoc.triggered.connect(self.mainGui.saveDocument)
 
         # Document > Close
         self.aCloseDoc = self.docuMenu.addAction(self.tr("Close Document"))
@@ -219,7 +220,7 @@ class GuiMainMenu(QMenuBar):
         # Document > Close Preview
         self.aCloseView = self.docuMenu.addAction(self.tr("Close Document View"))
         self.aCloseView.setShortcut("Ctrl+Shift+R")
-        self.aCloseView.triggered.connect(lambda: self.mainGui.closeDocViewer())
+        self.aCloseView.triggered.connect(self.mainGui.closeDocViewer)
 
         # Document > Separator
         self.docuMenu.addSeparator()
@@ -671,6 +672,12 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.SC_ULINE)
         )
 
+        # Shortcode Mark
+        self.aScMark = self.mShortcodes.addAction(self.tr("Highlight"))
+        self.aScMark.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.SC_MARK)
+        )
+
         # Shortcode Superscript
         self.aScSuper = self.mShortcodes.addAction(self.tr("Superscript"))
         self.aScSuper.triggered.connect(
@@ -686,29 +693,29 @@ class GuiMainMenu(QMenuBar):
         # Format > Separator
         self.fmtMenu.addSeparator()
 
-        # Format > Header 1 (Partition)
-        self.aFmtHead1 = self.fmtMenu.addAction(self.tr("Header 1 (Partition)"))
+        # Format > Heading 1 (Partition)
+        self.aFmtHead1 = self.fmtMenu.addAction(self.tr("Heading 1 (Partition)"))
         self.aFmtHead1.setShortcut("Ctrl+1")
         self.aFmtHead1.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H1)
         )
 
-        # Format > Header 2 (Chapter)
-        self.aFmtHead2 = self.fmtMenu.addAction(self.tr("Header 2 (Chapter)"))
+        # Format > Heading 2 (Chapter)
+        self.aFmtHead2 = self.fmtMenu.addAction(self.tr("Heading 2 (Chapter)"))
         self.aFmtHead2.setShortcut("Ctrl+2")
         self.aFmtHead2.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H2)
         )
 
-        # Format > Header 3 (Scene)
-        self.aFmtHead3 = self.fmtMenu.addAction(self.tr("Header 3 (Scene)"))
+        # Format > Heading 3 (Scene)
+        self.aFmtHead3 = self.fmtMenu.addAction(self.tr("Heading 3 (Scene)"))
         self.aFmtHead3.setShortcut("Ctrl+3")
         self.aFmtHead3.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H3)
         )
 
-        # Format > Header 4 (Section)
-        self.aFmtHead4 = self.fmtMenu.addAction(self.tr("Header 4 (Section)"))
+        # Format > Heading 4 (Section)
+        self.aFmtHead4 = self.fmtMenu.addAction(self.tr("Heading 4 (Section)"))
         self.aFmtHead4.setShortcut("Ctrl+4")
         self.aFmtHead4.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H4)
@@ -729,6 +736,12 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_UNN)
         )
 
+        # Format > Alternative Scene
+        self.aFmtHardSc = self.fmtMenu.addAction(self.tr("Alternative Scene"))
+        self.aFmtHardSc.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.BLOCK_HSC)
+        )
+
         # Format > Separator
         self.fmtMenu.addSeparator()
 
@@ -797,14 +810,14 @@ class GuiMainMenu(QMenuBar):
         # Format > Separator
         self.fmtMenu.addSeparator()
 
-        # Format > Replace Single Quotes
-        self.aFmtReplSng = self.fmtMenu.addAction(self.tr("Convert Single Quotes"))
+        # Format > Replace Straight Single Quotes
+        self.aFmtReplSng = self.fmtMenu.addAction(self.tr("Replace Straight Single Quotes"))
         self.aFmtReplSng.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.REPL_SNG)
         )
 
-        # Format > Replace Double Quotes
-        self.aFmtReplDbl = self.fmtMenu.addAction(self.tr("Convert Double Quotes"))
+        # Format > Replace Straight Double Quotes
+        self.aFmtReplDbl = self.fmtMenu.addAction(self.tr("Replace Straight Double Quotes"))
         self.aFmtReplDbl.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.REPL_DBL)
         )
@@ -849,6 +862,14 @@ class GuiMainMenu(QMenuBar):
         self.aReplaceNext.setShortcut("Ctrl+Shift+1")
         self.aReplaceNext.triggered.connect(lambda: self.mainGui.docEditor.replaceNext())
 
+        # Search > Separator
+        self.srcMenu.addSeparator()
+
+        # Search > Find in Project
+        self.aFindProj = self.srcMenu.addAction(self.tr("Find in Project"))
+        self.aFindProj.setShortcut("Ctrl+Shift+F")
+        self.aFindProj.triggered.connect(lambda: self.requestViewChange.emit(nwView.SEARCH))
+
         return
 
     def _buildToolsMenu(self) -> None:
